require "spec_helper"

describe JsonTest::Configuration do
  it "excludes id and timestamps by default" do
    JsonTest.excluded_keys.should eq ["id", "created_at", "updated_at"]
  end

  it "excludes custom keys" do
    JsonTest.exclude_keys("token")
    JsonTest.excluded_keys.should eq ["token"]
  end

  it "excludes custom keys via setter" do
    JsonTest.excluded_keys = ["token"]
    JsonTest.excluded_keys.should eq ["token"]
  end

  it "excludes custom keys via block" do
    JsonTest.configure { |c| c.exclude_keys("token") }
    JsonTest.excluded_keys.should eq ["token"]
  end

  it "excludes custom keys via block setter" do
    JsonTest.configure { |c| c.excluded_keys = ["token"] }
    JsonTest.excluded_keys.should eq ["token"]
  end

  it "excludes custom keys via instance-evaluated block" do
    JsonTest.configure{ exclude_keys("token") }
    JsonTest.excluded_keys.should eq ["token"]
  end

  it "ensures its excluded keys are strings" do
    JsonTest.exclude_keys(:token)
    JsonTest.excluded_keys.should eq ["token"]
  end

  it "ensures its excluded keys are unique" do
    JsonTest.exclude_keys("token", :token)
    JsonTest.excluded_keys.should eq ["token"]
  end

  it "resets its excluded keys" do
    original = JsonTest.excluded_keys

    JsonTest.exclude_keys("token")
    JsonTest.excluded_keys.should_not eq original

    JsonTest.reset
    JsonTest.excluded_keys.should eq original
  end

  it "resets its directory" do
    JsonTest.directory.should be_nil

    JsonTest.directory = "/"
    JsonTest.directory.should_not be_nil

    JsonTest.reset
    JsonTest.directory.should be_nil
  end
end
